@@ -3,9 +3,11 @@
 #' Functions to check if an object is a BibEntry, or coerce it if possible.
 #'
 #' @param x any \code{R} object.
-#' @details \code{as.BibEntry} is able to coerce suitably formatted character vectors, \code{\link{bibentry}} objects, lists,
+#' @details \code{as.BibEntry} is able to coerce suitably formatted character
+#' vectors, \code{\link{bibentry}} objects, lists,
 #' and data.frames to BibEntry objects.  See the examples.
-#' @note Each entry to be coerced should have a bibtype, key, and all required fields for the specified bibtype.
+#' @note Each entry to be coerced should have a bibtype, key, and all required
+#' fields for the specified bibtype.
 #' @return \code{as.BibEntry} - if successful, an object of class BibEntry.
 #' @aliases is.BibEntry
 #' @keywords utilities
@@ -47,12 +49,14 @@ as.BibEntry <- function(x){
         attr(y, "key") <- CreateBibKey(y[['title']], y[['author']], y[['year']])
       check <- try(.BibEntryCheckBibEntry1(y), TRUE)
       if (inherits(check, 'try-error')){
-        message(paste0('Ignoring entry titled \"', y[['title']], '\" because ', strsplit(check, '\\n[[:space:]]*')[[1]][2]))
+          message(gettextf('Ignoring entry titled %s because %s',
+                           dQuote(y[['title']]),
+                         strsplit(check, '\\n[[:space:]]*')[[1]][2]))
         return(NULL)
       }
       y
     })
-    x <- x[!sapply(x, is.null)]
+    x <- x[!vapply(x, is.null, FALSE)]
     if (length(x)){
       attributes(x) <- att
       class(x) <- c('BibEntry', 'bibentry')
@@ -78,7 +82,8 @@ as.BibEntry <- function(x){
     y <- vector('list', length(x))
     for (i in seq_len(nrow(x))){
       na.ind <- which(!is.na(x[i, ]))
-      y[[i]] <- as.BibEntry(c(setNames(as.character(x[i, na.ind]), .fields[na.ind]), key = keys[i]) )
+      y[[i]] <- as.BibEntry(c(setNames(as.character(x[i, na.ind]),
+                                       .fields[na.ind]), key = keys[i]))
     }
     y <- MakeCitationList(y)
     return(y)
@@ -94,19 +99,22 @@ as.BibEntry <- function(x){
       if (length(x[[1L]]) == 1L){
         x <- do.call(BibEntry, x)
       }else{
-        x <- sapply(x, function(...) do.call(BibEntry, as.list(...)))
-        class(x) <- c("BibEntry", "bibentry")
+        x <- lapply(x, function(...) do.call(BibEntry, as.list(...)))
+        x <- do.call("c", x)  # class(x) <- c("BibEntry", "bibentry")
       }
     }
   }else{
-    stop(paste0("Cannot coerce object of class '", class(x), "' to BibEntry"))
+    classes <- paste(class(x), collapse = ", ")
+    stop(gettextf("Cannot coerce object of class %s to BibEntry",
+                  sQuote(classes)))
   }
   x <- MakeKeysUnique(x)
   return(x)
 }
 
 #' @rdname as.BibEntry
-#' @return \code{is.BibEntry} - logical; \code{TRUE} if \code{x} is a BibEntry object.
+#' @return \code{is.BibEntry} - logical; \code{TRUE} if \code{x} is a BibEntry
+#' object.
 #' @export
 is.BibEntry <- function(x){
   inherits(x, "BibEntry")
